<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Travel Master Pro
 * @since Travel Master Pro 1.0.0
 * @return array An array of default values
 */

function travel_master_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$travel_master_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#fff',
		'header_tagline_color'			=> '#fff',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#00afe9',
		'colorscheme'					=> 'default',
		'theme_version'					=> 'lite-version',
		'home_layout'					=> 'default-design',
		
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',

		//body typography
		'body_font_family'			=> 'Muli',
		'body_font_weight'			=> 300,
		'body_font_size'			=> 16,
		'body_font_style'			=> 'normal',
		'body_text_transform'		=> 'none',

		//h1 typography
		'heading_h1_font_family'		=> 'Raleway',
		'heading_h1_font_weight'		=> 300,
		'heading_h1_text_transform'		=> 'none',
		'heading_h1_font_style'			=> 'normal',

		//h2 typography
		'heading_h2_font_family'		=> 'Raleway',
		'heading_h2_font_weight'		=> 700,
		'heading_h2_text_transform'		=> 'none',
		'heading_h2_font_style'			=> 'normal',

		//h3 typography
		'heading_h3_font_family'		=> 'Raleway',
		'heading_h3_font_weight'		=> 700,
		'heading_h3_text_transform'		=> 'none',
		'heading_h3_font_style'			=> 'normal',

		//h4 typography
		'heading_h4_font_family'		=> 'Raleway',
		'heading_h4_font_weight'		=> 700,
		'heading_h4_text_transform'		=> 'none',
		'heading_h4_font_style'			=> 'normal',

		//h5 typography
		'heading_h5_font_family'		=> 'Raleway',
		'heading_h5_font_weight'		=> 700,
		'heading_h5_text_transform'		=> 'none',
		'heading_h5_font_style'			=> 'normal',

		//h6 typography
		'heading_h6_font_family'		=> 'Raleway',
		'heading_h6_font_weight'		=> 700,
		'heading_h6_text_transform'		=> 'none',
		'heading_h6_font_style'			=> 'normal',

		//p typography
		'heading_p_font_family'			=> 'Muli',
		'heading_p_font_weight'			=> 400,
		'heading_p_text_transform'		=> 'none',
		'heading_p_font_style'			=> 'normal',

		//button
		'button_background_color'		=> '#e5f8fc',
		'button_text_color'		=> '#00afe9',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide-layout',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,
		'social_nav_enable'				=> true,


		// excerpt options
		'long_excerpt_length'           => 25,
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s', '1: Year, 2: Site Title with home URL', 'travel-master-pro' ), '[the-year]', '[site-link]' ),
		'powered_by_text'           	=> esc_html__( 'All Rights Reserved | ', 'travel-master-pro' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'travel-master-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// homepage sections sortable
		'sortable' 						=> 'slider,trip_search,featured,popular_destination,about,project,package,traveler_choice,service,video,video_gallery,blog,discover_places,testimonial,subscription',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'travel-master-pro' ),
		'hide_date' 					=> false,
		'hide_category'					=> false,
		'hide_author'					=> false,

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		/* Front Page */

		// Slider
		'slider_section_enable'			=> true,
		'slider_autoplay'				=> false,
		'slider_content_type'			=> 'category',
		'slider_count'					=> 3,
		'slider_btn_label'				=> esc_html__( 'Discover More', 'travel-master-pro' ),
		'slider_video_label'			=> esc_html__( 'Watch the video', 'travel-master-pro' ),


		// trip search
		'trip_search_section_enable'	=> true,
		'trip_search_placeholder_1'		=> esc_html__( 'Ex: Trekking', 'travel-master-pro' ),
		'trip_search_placeholder_2'		=> esc_html__( 'Trip Type', 'travel-master-pro' ),
		'trip_search_placeholder_3'		=> esc_html__( 'Destination', 'travel-master-pro' ),

		// featured
		'featured_title'				=> esc_html__( 'FEATURED POSTS', 'travel-master-pro' ),
		'featured_section_enable'		=> true,
		'featured_content_type'			=> 'category',
		'featured_count'				=> 4,
		'featured_read_more'			=> esc_html__( 'See Details', 'travel-master-pro' ),

		// popular destination
		'popular_destination_section_enable'	=> true,
		'popular_destination_content_type'		=> 'category',
		'popular_destination_column_type'		=> 4,
		'popular_destination_count'				=> 4,
		'popular_destination_title'				=> esc_html__( 'Popular Trips', 'travel-master-pro' ),
		'popular_destination_btn_title'			=> esc_html__( 'See More', 'travel-master-pro' ),
		'popular_destination_read_more'			=> esc_html__( 'See Details', 'travel-master-pro' ),

		// about
		'about_section_enable'			=> true,
		'about_content_type'			=> 'page',
		'about_title'					=> esc_html__( 'Go places you&#39;ve dreamed of', 'travel-master-pro' ),
		'about_sub_title'				=> esc_html__( 'About Us', 'travel-master-pro' ),
		'about_description'				=> esc_html__( 'Between the many mouths to feed, entry to myriad attractions and school holiday price hikes, traveling with kids can quickly add up. Follow these top tips to make your hard-earned cash go further as you and your brood explore the world...', 'travel-master-pro' ),
		'about_btn_title'				=> esc_html__( 'Explore More', 'travel-master-pro' ),

		// project
		'project_section_enable'			=> false,
		'project_content_type'			=> 'page',
		'project_title'					=> esc_html__( 'OUR PROJECTS', 'travel-master-pro' ),
		'project_btn_title'				=> esc_html__( 'View All Project', 'travel-master-pro' ),

		// package
		'package_section_enable'		=> true,
		'package_content_type'			=> 'category',
		'package_title'					=> esc_html__( 'Recommended Packages', 'travel-master-pro' ),
		'package_btn_title'				=> esc_html__( 'View all packages', 'travel-master-pro' ),

		// traveler_choice
		'traveler_choice_section_enable'	=> true,
		'traveler_choice_autoplay'			=> true,
		'traveler_choice_content_type'		=> 'category',
		'traveler_choice_count'				=> 3,
		'traveler_choice_read_more'			=> esc_html__( 'Book This Trip', 'travel-master-pro' ),

		// service
		'service_section_enable'		=> true,
		'service_section_icon_enable'	=> true,
		'service_content_type'			=> 'category',
		'service_count'					=> 3,

		// video
		'video_section_enable'			=> false,
		'video_content_type'			=> 'category',
		'video_count'					=> 5,
		'video_title'					=> esc_html__( 'Travel Videos', 'travel-master-pro' ),
		'video_btn_title'				=> esc_html__( 'View All Video', 'travel-master-pro' ),

		// video_gallery
		'video_gallery_section_enable'	=> true,
		'video_gallery_content_type'	=> 'post',
		'video_gallery_video_title'		=> esc_html__( 'Travel Videos', 'travel-master-pro' ),
		'video_gallery_sub_title'		=> esc_html__( 'Video of the day', 'travel-master-pro' ),
		'video_gallery_title'			=> esc_html__( 'The tallest living terrestrial animals and ruminants!', 'travel-master-pro' ),
		'video_gallery_post_title'		=> esc_html__( 'Gallery Posts', 'travel-master-pro' ),
		
		//services
		'service_title'					=> esc_html__( 'We Are In A Mission To Help The Helpless', 'travel-master-pro' ),

		// blog
		'blog_section_enable'			=> true,
		'blog_content_type'				=> 'recent',
		'blog_count'					=> 4,
		'blog_title'					=> esc_html__( 'Amazing travel Articles', 'travel-master-pro' ),
		'blog_btn_title'				=> esc_html__( 'View All Articles', 'travel-master-pro' ),

		// discover places
		'discover_places_section_enable'	=> true,
		'discover_places_auto_play'			=> false,
		'discover_places_content_type'		=> 'category',
		'discover_places_count'				=> 3,
		'discover_places_sub_title'			=> esc_html__( 'Last Minute', 'travel-master-pro' ),
		'discover_places_read_more'			=> esc_html__( 'View Details', 'travel-master-pro' ),

		// testimonial
		'testimonial_section_enable'	=> true,
		'testimonial_auto_play'			=> false,
		'testimonial_content_type'		=> 'category',
		'testimonial_count'				=> 4,
		'testimonial_section_title'		=> esc_html__( 'What Our Clients Says', 'travel-master-pro' ),

		// subscription
		'subscription_section_enable'	=> true,
		'subscription_sub_title'		=> esc_html__( 'Keep in touch', 'travel-master-pro' ),
		'subscription_title'			=> esc_html__( 'Travel with us!', 'travel-master-pro' ),
		'subscription_btn_title'		=> esc_html__( 'Subscribe Now', 'travel-master-pro' ),

		// popular
		'popular_section_enable'			=> true,
		'popular_content_type'				=> 'category',
		'popular_count'						=> 3,

		// recent
		'recent_section_enable'			=> true,
		'recent_title'					=> esc_html__( 'RECENT POSTS', 'travel-master-pro' ),
		'recent_content_type'			=> 'category',
		'recent_count'					=> 3,

		// most_view
		'most_view_section_enable'			=> true,
		'most_view_content_type'			=> 'category',
		'most_view_count'					=> 4,
		'most_view_title'					=> esc_html__( 'MOST VIEWED POSTS', 'travel-master-pro' ),

		// popular product
		'popular_product_section_enable'	=> true,
		'popular_product_title'				=> esc_html__( 'Popular Products', 'travel-master-pro' ),
		'popular_product_description'		=> esc_html__( 'Latest spring collection for fashionable person like you.', 'travel-master-pro' ),
		'popular_product_count'				=> 4,
		'popular_product_content_type'		=> 'product',

		// latest Product
		'latest_product_section_enable'		=> true,
		'latest_product_title'				=> esc_html__( 'NEW ARRIVALS', 'travel-master-pro' ),
		'latest_product_description'		=> esc_html__( 'All Styles in This Spring', 'travel-master-pro' ),
		'latest_product_count'				=> 4,
		'latest_product_content_type'		=> 'product',

		// Featured Product
		'featured_product_section_enable'		=> true,
		'latest_product_title'				=> esc_html__( 'NEW ARRIVALS', 'travel-master-pro' ),
		'latest_product_description'		=> esc_html__( 'All Styles in This Spring', 'travel-master-pro' ),
		'latest_product_count'				=> 4,
		'featured_product_content_type'		=> 'category',

		// Team 
		'team_section_enable'		=> true,
		'team_title'				=> esc_html__( 'OUR EXPERT VOLUNTEER', 'travel-master-pro' ),
		'team_count'				=> 4,
		'team_content_type'			=> 'category',

		// CTA 
		'cta_section_enable'		=> true,
		'cta_title'				=> esc_html__( 'We need Volunteers around the World', 'travel-master-pro' ),
		'cta_btn_title'				=> esc_html__( 'Donate Now', 'travel-master-pro' ),
		'cta_content_type'			=> 'page',

		//advertisement
		'advertisement_section_enable'			=> true,
	);

	$output = apply_filters( 'travel_master_pro_default_theme_options', $travel_master_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}