<?php
/**
 * Video Gallery Section options
 *
 * @package Theme Palace
 * @subpackage Travel Master Pro
 * @since Travel Master Pro 1.0.0
 */

// Add Video Gallery section
$wp_customize->add_section( 'travel_master_pro_video_gallery_section', array(
	'title'             => esc_html__( 'Video Gallery','travel-master-pro' ),
	'description'       => esc_html__( 'Video Gallery Section options.', 'travel-master-pro' ),
	'panel'             => 'travel_master_pro_front_page_panel',
) );

// Video Gallery content enable control and setting
$wp_customize->add_setting( 'travel_master_pro_theme_options[video_gallery_section_enable]', array(
	'default'			=> 	$options['video_gallery_section_enable'],
	'sanitize_callback' => 'travel_master_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Travel_Master_Pro_Switch_Control( $wp_customize, 'travel_master_pro_theme_options[video_gallery_section_enable]', array(
	'label'             => esc_html__( 'Video Gallery Section Enable', 'travel-master-pro' ),
	'section'           => 'travel_master_pro_video_gallery_section',
	'on_off_label' 		=> travel_master_pro_switch_options(),
) ) );

// video_gallery sub title setting and control
$wp_customize->add_setting( 'travel_master_pro_theme_options[video_gallery_video_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['video_gallery_video_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_master_pro_theme_options[video_gallery_video_title]', array(
	'label'           	=> esc_html__( 'Video Title', 'travel-master-pro' ),
	'section'        	=> 'travel_master_pro_video_gallery_section',
	'active_callback' 	=> 'travel_master_pro_is_video_gallery_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_master_pro_theme_options[video_gallery_video_title]', array(
		'selector'            => '#featured-videos .video-wrapper .section-header h2.section-title',
		'settings'            => 'travel_master_pro_theme_options[video_gallery_video_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_master_pro_video_gallery_video_title_partial',
    ) );
}

// video_gallery video url setting and control
$wp_customize->add_setting( 'travel_master_pro_theme_options[video_gallery_video_url]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'travel_master_pro_theme_options[video_gallery_video_url]', array(
	'label'           	=> esc_html__( 'Video url', 'travel-master-pro' ),
	'section'        	=> 'travel_master_pro_video_gallery_section',
	'active_callback' 	=> 'travel_master_pro_is_video_gallery_section_enable',
	'type'				=> 'url',
) );

// video_gallery sub title setting and control
$wp_customize->add_setting( 'travel_master_pro_theme_options[video_gallery_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['video_gallery_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_master_pro_theme_options[video_gallery_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'travel-master-pro' ),
	'section'        	=> 'travel_master_pro_video_gallery_section',
	'active_callback' 	=> 'travel_master_pro_is_video_gallery_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_master_pro_theme_options[video_gallery_sub_title]', array(
		'selector'            => '#featured-videos .video-wrapper .entry-container span.section-subtitle',
		'settings'            => 'travel_master_pro_theme_options[video_gallery_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_master_pro_video_gallery_sub_title_partial',
    ) );
}

// video_gallery title setting and control
$wp_customize->add_setting( 'travel_master_pro_theme_options[video_gallery_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['video_gallery_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_master_pro_theme_options[video_gallery_title]', array(
	'label'           	=> esc_html__( 'Title', 'travel-master-pro' ),
	'section'        	=> 'travel_master_pro_video_gallery_section',
	'active_callback' 	=> 'travel_master_pro_is_video_gallery_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_master_pro_theme_options[video_gallery_title]', array(
		'selector'            => '#featured-videos .video-wrapper .entry-container .entry-header h2.entry-title',
		'settings'            => 'travel_master_pro_theme_options[video_gallery_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_master_pro_video_gallery_title_partial',
    ) );
}

// video_gallery hr setting and control
$wp_customize->add_setting( 'travel_master_pro_theme_options[video_gallery_hr]', array(
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( new Travel_Master_Pro_Customize_Horizontal_Line( $wp_customize, 'travel_master_pro_theme_options[video_gallery_hr]',
	array(
		'section'         => 'travel_master_pro_video_gallery_section',
		'active_callback' => 'travel_master_pro_is_video_gallery_section_enable',
		'type'			  => 'hr'
) ) );

// video_gallery post title setting and control
$wp_customize->add_setting( 'travel_master_pro_theme_options[video_gallery_post_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['video_gallery_post_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'travel_master_pro_theme_options[video_gallery_post_title]', array(
	'label'           	=> esc_html__( 'Post Title', 'travel-master-pro' ),
	'section'        	=> 'travel_master_pro_video_gallery_section',
	'active_callback' 	=> 'travel_master_pro_is_video_gallery_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'travel_master_pro_theme_options[video_gallery_post_title]', array(
		'selector'            => '#featured-videos .photos-wrapper .section-header h2.section-title',
		'settings'            => 'travel_master_pro_theme_options[video_gallery_post_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'travel_master_pro_video_gallery_post_title_partial',
    ) );
}

// Video Gallery content type control and setting
$wp_customize->add_setting( 'travel_master_pro_theme_options[video_gallery_content_type]', array(
	'default'          	=> $options['video_gallery_content_type'],
	'sanitize_callback' => 'travel_master_pro_sanitize_select',
) );

$wp_customize->add_control( 'travel_master_pro_theme_options[video_gallery_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'travel-master-pro' ),
	'section'           => 'travel_master_pro_video_gallery_section',
	'type'				=> 'select',
	'active_callback' 	=> 'travel_master_pro_is_video_gallery_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'travel-master-pro' ),
		'post' 		=> esc_html__( 'Post', 'travel-master-pro' ),
	),
) );

for ( $i = 1; $i <= 2; $i++ ) :

	// video_gallery pages drop down chooser control and setting
	$wp_customize->add_setting( 'travel_master_pro_theme_options[video_gallery_content_page_' . $i . ']', array(
		'sanitize_callback' => 'travel_master_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travel_Master_Pro_Dropdown_Chooser( $wp_customize, 'travel_master_pro_theme_options[video_gallery_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'travel-master-pro' ), $i ),
		'section'           => 'travel_master_pro_video_gallery_section',
		'choices'			=> travel_master_pro_page_choices(),
		'active_callback'	=> 'travel_master_pro_is_video_gallery_section_content_page_enable',
	) ) );

	// video_gallery posts drop down chooser control and setting
	$wp_customize->add_setting( 'travel_master_pro_theme_options[video_gallery_content_post_' . $i . ']', array(
		'sanitize_callback' => 'travel_master_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Travel_Master_Pro_Dropdown_Chooser( $wp_customize, 'travel_master_pro_theme_options[video_gallery_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'travel-master-pro' ), $i ),
		'section'           => 'travel_master_pro_video_gallery_section',
		'choices'			=> travel_master_pro_post_choices(),
		'active_callback'	=> 'travel_master_pro_is_video_gallery_section_content_post_enable',
	) ) );

endfor;
